#ifndef _tools_h
#define _tools_h

#include <stdarg.h>
#include <sys/types.h>

#ifndef min
#define min(x,y) ((x) < (y) ? (x) : (y))
#endif

#ifndef max
#define max(x,y) ((x) > (y) ? (x) : (y))
#endif


/*
 * Dup a structure
 */
#define DUP(s) memcpy(malloc(sizeof(s)), &(s), sizeof(s))

#ifdef VISUALCPP
#define log LOG
#endif

void Log (int lev, char *s,...);

#define LOGINT(v) Log(6, "%s=%i\n", #v, (int)(v))

/*
 * Compare strings ignoring case
 */
int stricmp (const char *s1, const char *s2);
int memicmp (const void *s1, const void *s2, size_t n);
int strnicmp (const char *s1, const char *s2, size_t n);

/*
 * Src is a source string, n is a word number (1...), returned string must
 * be free()'d. If subst_vars == 1 env. vars will be substed for %VAR%.
 * Returns 0 if there is no word #n.
 */
char *getwordx (char *src, int n, int subst_vars);

#define getword(src, n) getwordx(src, n, 1)

/*
 * Copyes not more than len chars from src into dst, but, unlike strncpy(),
 * it appends '\0' even if src is longer than len.
 */
char *strnzcpy (char *dst, const char *src, size_t len);
char *strnzcat (char *dst, const char *src, size_t len);

/*
 * Quotes all control chars. free() it's retval!
 */
char *strquote (char *s);

/*
 * Removes control chars
 */
char *strwipe (char *s);

/*
 * 1 -- created, 0 -- already busy
 */
int create_sem_file (char *s);

/*
 */
long rnd ();

/*
 * Makes all dirs in the path
 */
int mkpath (char *s);

/*
 * Splits args ASCIIZ string onto argc separate words,
 * saves them as argv[0]...argv[argc-1]. Logs error
 * "ID: cannot parse args", if args containes less than argc words.
 */
int parse_args (int argc, char *argv[], char *src, char *ID);

#endif
